summaryrefslogtreecommitdiffstats
path: root/kpresenter/KPrSideBar.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /kpresenter/KPrSideBar.cpp
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kpresenter/KPrSideBar.cpp')
-rw-r--r--kpresenter/KPrSideBar.cpp56
1 files changed, 28 insertions, 28 deletions
diff --git a/kpresenter/KPrSideBar.cpp b/kpresenter/KPrSideBar.cpp
index a1077a17..b39ab5b0 100644
--- a/kpresenter/KPrSideBar.cpp
+++ b/kpresenter/KPrSideBar.cpp
@@ -69,9 +69,9 @@ TQValidator::State KPrRenamePageValidator::validate( TQString & input, int& ) co
class ThumbToolTip : public TQToolTip
{
public:
- ThumbToolTip( KPrThumbBar *tqparent )
- : TQToolTip( tqparent->viewport() )
- , m_thumbBar( tqparent )
+ ThumbToolTip( KPrThumbBar *parent )
+ : TQToolTip( parent->viewport() )
+ , m_thumbBar( parent )
{}
protected:
@@ -92,8 +92,8 @@ private:
class OutlineSlideItem: public KListViewItem
{
public:
- OutlineSlideItem( KListView * tqparent, KPrPage* page, bool _masterPage );
- OutlineSlideItem( KListView * tqparent, OutlineSlideItem *after, KPrPage* page, bool _masterPage );
+ OutlineSlideItem( KListView * parent, KPrPage* page, bool _masterPage );
+ OutlineSlideItem( KListView * parent, OutlineSlideItem *after, KPrPage* page, bool _masterPage );
KPrPage* page() const { return m_page; }
@@ -110,7 +110,7 @@ private:
class OutlineObjectItem: public KListViewItem
{
public:
- OutlineObjectItem( OutlineSlideItem * tqparent, KPrObject* object,
+ OutlineObjectItem( OutlineSlideItem * parent, KPrObject* object,
const TQString& name = TQString() );
KPrObject* object() const { return m_object; }
@@ -124,11 +124,11 @@ private:
class ThumbItem : public TQIconViewItem
{
public:
- ThumbItem( TQIconView *tqparent, const TQString & text, const TQPixmap & icon )
- : TQIconViewItem( tqparent, text, icon )
+ ThumbItem( TQIconView *parent, const TQString & text, const TQPixmap & icon )
+ : TQIconViewItem( parent, text, icon )
{ uptodate = true; }
- ThumbItem( TQIconView *tqparent, TQIconViewItem *after, const TQString & text, const TQPixmap & icon )
- : TQIconViewItem( tqparent, after, text, icon )
+ ThumbItem( TQIconView *parent, TQIconViewItem *after, const TQString & text, const TQPixmap & icon )
+ : TQIconViewItem( parent, after, text, icon )
{ uptodate = true; }
virtual bool isUptodate() { return uptodate; };
@@ -138,8 +138,8 @@ private:
bool uptodate;
};
-KPrSideBar::KPrSideBar(TQWidget *tqparent, KPrDocument *d, KPrView *v)
- :TQTabWidget(tqparent), m_doc(d), m_view(v)
+KPrSideBar::KPrSideBar(TQWidget *parent, KPrDocument *d, KPrView *v)
+ :TQTabWidget(parent), m_doc(d), m_view(v)
{
setTabPosition(TQTabWidget::Top);
setTabShape(TQTabWidget::Triangular);
@@ -233,8 +233,8 @@ void KPrSideBarBase::setViewMasterPage( bool _b )
m_viewMasterPage = _b;
}
-KPrThumbBar::KPrThumbBar(TQWidget *tqparent, KPrDocument *d, KPrView *v)
- :KIconView(tqparent), KPrSideBarBase( d,v)
+KPrThumbBar::KPrThumbBar(TQWidget *parent, KPrDocument *d, KPrView *v)
+ :KIconView(parent), KPrSideBarBase( d,v)
{
uptodate = false;
m_offsetX = 0;
@@ -577,16 +577,16 @@ void KPrThumbBar::slotRefreshItems()
refreshItems();
}
-OutlineSlideItem::OutlineSlideItem( KListView* tqparent, KPrPage* _page, bool _masterPage )
- : KListViewItem( tqparent ), m_page( _page ), m_masterPage( _masterPage )
+OutlineSlideItem::OutlineSlideItem( KListView* parent, KPrPage* _page, bool _masterPage )
+ : KListViewItem( parent ), m_page( _page ), m_masterPage( _masterPage )
{
setDragEnabled(true);
setPage( _page );
setPixmap( 0, KPBarIcon( "slide" ) );
}
-OutlineSlideItem::OutlineSlideItem( KListView* tqparent, OutlineSlideItem * after, KPrPage* _page, bool _masterPage )
- : KListViewItem( tqparent, after ), m_page( _page ), m_masterPage( _masterPage )
+OutlineSlideItem::OutlineSlideItem( KListView* parent, OutlineSlideItem * after, KPrPage* _page, bool _masterPage )
+ : KListViewItem( parent, after ), m_page( _page ), m_masterPage( _masterPage )
{
setDragEnabled(true);
setPage( _page );
@@ -676,9 +676,9 @@ void OutlineSlideItem::updateTitle()
setText( 0, title );
}
-OutlineObjectItem::OutlineObjectItem( OutlineSlideItem* tqparent, KPrObject* _object,
+OutlineObjectItem::OutlineObjectItem( OutlineSlideItem* parent, KPrObject* _object,
const TQString& name )
- : KListViewItem( tqparent ), m_object( _object )
+ : KListViewItem( parent ), m_object( _object )
{
setObject( m_object );
setDragEnabled( false );
@@ -755,8 +755,8 @@ void OutlineObjectItem::setObject( KPrObject* object )
}
}
-KPrOutline::KPrOutline( TQWidget *tqparent, KPrDocument *d, KPrView *v )
- : KListView( tqparent ), KPrSideBarBase( d, v)
+KPrOutline::KPrOutline( TQWidget *parent, KPrDocument *d, KPrView *v )
+ : KListView( parent ), KPrSideBarBase( d, v)
{
rebuildItems();
setSorting( -1 );
@@ -922,7 +922,7 @@ void KPrOutline::itemClicked( TQListViewItem *item )
if( !object ) return;
// ensure the owner slide is shown first
- OutlineSlideItem* slideItem = dynamic_cast<OutlineSlideItem*>(objectItem->tqparent());
+ OutlineSlideItem* slideItem = dynamic_cast<OutlineSlideItem*>(objectItem->parent());
if( slideItem && m_doc->activePage() != slideItem->page() )
{
KPrPage* page = slideItem->page();
@@ -946,12 +946,12 @@ void KPrOutline::itemClicked( TQListViewItem *item )
* When an item is about to move (using drag-and-drop), it makes shure that
* it's not moved right after an object.
*/
-void KPrOutline::slotDropped( TQDropEvent * /* e */, TQListViewItem *tqparent, TQListViewItem *target )
+void KPrOutline::slotDropped( TQDropEvent * /* e */, TQListViewItem *parent, TQListViewItem *target )
{
kdDebug(33001) << "slotDropped" << endl;
/* slide doesn't have tqparent (always 0)
* Only slides can move at the moment, objects can't. */
- if ( tqparent )
+ if ( parent )
return;
// This code is taken from KListView
@@ -969,7 +969,7 @@ void KPrOutline::slotDropped( TQDropEvent * /* e */, TQListViewItem *tqparent, T
i->setSelected( false );
// don't move the item as it is allready
- moveItem(i, tqparent, target );
+ moveItem(i, parent, target );
// Only one item can be moved
break;
@@ -987,7 +987,7 @@ bool KPrOutline::acceptDrag( TQDropEvent* e ) const
void KPrOutline::setCurrentPage( int pg )
{
OutlineSlideItem *item = slideItem( pg );
- if( item && ( item!=currentItem()->tqparent() ) )
+ if( item && ( item!=currentItem()->parent() ) )
{
blockSignals( true );
setCurrentItem( item );
@@ -946,12 +946,12 @@ void KPrOutline::itemClicked( TQListViewItem *item )
{
kdDebug(33001) << "slotDropped" << endl;
- /* slide doesn't have tqparent (always 0)
+ /* slide doesn't have parent (always 0)
* Only slides can move at the moment, objects can't. */